@@ -1,22 +1,20 @@
 /*
-  Copyright (C) 2005, 2007 Marius L. Jhndal
- 
+  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Marius L. Jøhndal
+
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.
- 
+
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.
- 
+
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- 
-  $Id: rss.h,v 1.2 2007/09/20 18:10:51 mariuslj Exp $
-  
+
 */
 
 #ifndef RSS_H
@@ -47,16 +45,7 @@ typedef struct _rss_file {
 } rss_file;
 
 rss_file *rss_open_file(const char *filename);
-rss_file *rss_open_url(const char *url);
+rss_file *rss_open_url(const char *url, int debug);
 void rss_close(rss_file *f);
 
 #endif /* RSS_H */
-
-/* 
-   Local Variables:
-   mode:c
-   indent-tabs-mode:nil
-   c-basic-offset:2
-   End:
-*/
-
